=== modified file 'include/drizzle.h'
--- include/drizzle.h	2008-07-28 03:45:43 +0000
+++ include/drizzle.h	2008-07-28 05:38:21 +0000
@@ -299,7 +299,7 @@
   connection.  All uses of the connection(s) should be between these
   function calls.
 */
-my_bool STDCALL drizzle_thread_init(void);
+bool STDCALL drizzle_thread_init(void);
 void STDCALL drizzle_thread_end(void);
 
 /*
@@ -309,7 +309,7 @@
 
 uint64_t STDCALL drizzle_num_rows(DRIZZLE_RES *res);
 unsigned int STDCALL drizzle_num_fields(DRIZZLE_RES *res);
-my_bool STDCALL drizzle_eof(DRIZZLE_RES *res);
+bool STDCALL drizzle_eof(DRIZZLE_RES *res);
 DRIZZLE_FIELD *STDCALL drizzle_fetch_field_direct(DRIZZLE_RES *res,
                 unsigned int fieldnr);
 DRIZZLE_FIELD * STDCALL drizzle_fetch_fields(DRIZZLE_RES *res);
@@ -329,7 +329,7 @@
 int32_t          STDCALL drizzle_set_character_set(DRIZZLE *drizzle, const char *csname);
 
 DRIZZLE * STDCALL drizzle_create(DRIZZLE *drizzle);
-my_bool   STDCALL drizzle_change_user(DRIZZLE *drizzle, const char *user,
+bool   STDCALL drizzle_change_user(DRIZZLE *drizzle, const char *user,
             const char *passwd, const char *db);
 DRIZZLE * STDCALL drizzle_connect(DRIZZLE *drizzle, const char *host,
              const char *user,
@@ -392,8 +392,8 @@
 uint32_t        STDCALL drizzle_real_escape_string(DRIZZLE *drizzle, char *to, const char *from, uint32_t length);
 void    STDCALL myodbc_remove_escape(DRIZZLE *drizzle,char *name);
 uint32_t  STDCALL drizzle_thread_safe(void);
-my_bool    STDCALL drizzle_embedded(void);
-my_bool         STDCALL drizzle_read_query_result(DRIZZLE *drizzle);
+bool    STDCALL drizzle_embedded(void);
+bool         STDCALL drizzle_read_query_result(DRIZZLE *drizzle);
 
 
 
@@ -419,10 +419,10 @@
 } DRIZZLE_METHODS;
 
 
-my_bool STDCALL drizzle_commit(DRIZZLE *drizzle);
-my_bool STDCALL drizzle_rollback(DRIZZLE *drizzle);
-my_bool STDCALL drizzle_autocommit(DRIZZLE *drizzle, my_bool auto_mode);
-my_bool STDCALL drizzle_more_results(DRIZZLE *drizzle);
+bool STDCALL drizzle_commit(DRIZZLE *drizzle);
+bool STDCALL drizzle_rollback(DRIZZLE *drizzle);
+bool STDCALL drizzle_autocommit(DRIZZLE *drizzle, bool auto_mode);
+bool STDCALL drizzle_more_results(DRIZZLE *drizzle);
 int STDCALL drizzle_next_result(DRIZZLE *drizzle);
 void STDCALL drizzle_close(DRIZZLE *sock);
 

=== modified file 'libdrizzle/client_settings.h'
--- libdrizzle/client_settings.h	2008-07-24 16:57:40 +0000
+++ libdrizzle/client_settings.h	2008-07-28 04:32:34 +0000
@@ -19,7 +19,7 @@
 
 sig_handler my_pipe_sig_handler(int sig);
 void read_user_name(char *name);
-my_bool handle_local_infile(DRIZZLE *drizzle, const char *net_filename);
+bool handle_local_infile(DRIZZLE *drizzle, const char *net_filename);
 
 
 /* TODO: Do we still need these now that there's not non-threaded stuff? */

=== modified file 'libdrizzle/libdrizzle.c'
--- libdrizzle/libdrizzle.c	2008-07-24 18:35:57 +0000
+++ libdrizzle/libdrizzle.c	2008-07-28 04:32:34 +0000
@@ -87,7 +87,7 @@
   return &drizzle_internal_parameters;
 }
 
-my_bool STDCALL drizzle_thread_init()
+bool STDCALL drizzle_thread_init()
 {
   return my_thread_init();
 }
@@ -151,8 +151,8 @@
   {
     if (!(res=drizzle_connect(drizzle,host,user,passwd,NullS,0,NullS,0)))
     {
-      if (drizzle->free_me)
-  my_free((uchar*) drizzle,MYF(0));
+      if (drizzle->free_me && drizzle)
+        free((uchar*) drizzle);
     }
     drizzle->reconnect= 1;
     return(res);
@@ -179,7 +179,7 @@
   return 0;
 }
 
-my_bool  STDCALL drizzle_change_user(DRIZZLE *drizzle, const char *user,
+bool STDCALL drizzle_change_user(DRIZZLE *drizzle, const char *user,
           const char *passwd, const char *db)
 {
   char buff[USERNAME_LENGTH+SCRAMBLED_PASSWORD_CHAR_LENGTH+NAME_LEN+2];
@@ -235,9 +235,12 @@
   if (rc == 0)
   {
     /* Free old connect information */
-    my_free(drizzle->user,MYF(MY_ALLOW_ZERO_PTR));
-    my_free(drizzle->passwd,MYF(MY_ALLOW_ZERO_PTR));
-    my_free(drizzle->db,MYF(MY_ALLOW_ZERO_PTR));
+    if(drizzle->user)
+      free(drizzle->user);
+    if(drizzle->passwd)
+      free(drizzle->passwd);
+    if(drizzle->db)
+      free(drizzle->db);
 
     /* alloc new connect information */
     drizzle->user=  my_strdup(user,MYF(MY_WME));
@@ -284,9 +287,9 @@
   return;
 }
 
-my_bool handle_local_infile(DRIZZLE *drizzle, const char *net_filename)
+bool handle_local_infile(DRIZZLE *drizzle, const char *net_filename)
 {
-  my_bool result= 1;
+  bool result= true;
   uint packet_length=MY_ALIGN(drizzle->net.max_packet-16,IO_SIZE);
   NET *net= &drizzle->net;
   int readcount;
@@ -305,7 +308,7 @@
   }
 
   /* copy filename into local memory and allocate read buffer */
-  if (!(buf=my_malloc(packet_length, MYF(0))))
+  if (!(buf=malloc(packet_length)))
   {
     set_drizzle_error(drizzle, CR_OUT_OF_MEMORY, unknown_sqlstate);
     return(1);
@@ -352,12 +355,13 @@
     goto err;
   }
 
-  result=0;          /* Ok */
+  result=false;					/* Ok */
 
 err:
   /* free up memory allocated with _init, usually */
   (*options->local_infile_end)(li_ptr);
-  my_free(buf, MYF(0));
+  if(buf)
+    free(buf);
   return(result);
 }
 
@@ -400,7 +404,7 @@
   char tmp_name[FN_REFLEN];
 
   if (!(*ptr= data= ((default_local_infile_data *)
-         my_malloc(sizeof(default_local_infile_data),  MYF(0)))))
+		     malloc(sizeof(default_local_infile_data)))))
     return 1; /* out of memory */
 
   data->error_msg[0]= 0;
@@ -468,7 +472,7 @@
   {
     if (data->fd >= 0)
       my_close(data->fd, MYF(MY_WME));
-    my_free(ptr, MYF(MY_WME));
+    free(ptr);
   }
 }
 
@@ -660,8 +664,7 @@
       !(fields= (*drizzle->methods->list_fields)(drizzle)))
     return(NULL);
 
-  if (!(result = (DRIZZLE_RES *) my_malloc(sizeof(DRIZZLE_RES),
-           MYF(MY_WME | MY_ZEROFILL))))
+  if (!(result = (DRIZZLE_RES *) malloc(sizeof(DRIZZLE_RES))))
     return(NULL);
 
   result->methods= drizzle->methods;
@@ -814,7 +817,7 @@
   return MYSQL_VERSION_ID;
 }
 
-my_bool STDCALL drizzle_eof(DRIZZLE_RES *res)
+bool STDCALL drizzle_eof(DRIZZLE_RES *res)
 {
   return res->eof;
 }
@@ -903,12 +906,12 @@
 }
 
 
-my_bool STDCALL drizzle_embedded(void)
+bool STDCALL drizzle_embedded(void)
 {
 #ifdef EMBEDDED_LIBRARY
-  return 1;
+  return true;
 #else
-  return 0;
+  return false;
 #endif
 }
 
@@ -990,7 +993,7 @@
 {
   char *to;
 #ifdef USE_MB
-  my_bool use_mb_flag=use_mb(drizzle->charset);
+  bool use_mb_flag=use_mb(drizzle->charset);
   char *end=NULL;
   if (use_mb_flag)
     for (end=name; *end ; end++) ;
@@ -1033,18 +1036,18 @@
   Commit the current transaction
 */
 
-my_bool STDCALL drizzle_commit(DRIZZLE *drizzle)
+bool STDCALL drizzle_commit(DRIZZLE *drizzle)
 {
-  return((my_bool) drizzle_real_query(drizzle, "commit", 6));
+  return((bool) drizzle_real_query(drizzle, "commit", 6));
 }
 
 /*
   Rollback the current transaction
 */
 
-my_bool STDCALL drizzle_rollback(DRIZZLE *drizzle)
+bool STDCALL drizzle_rollback(DRIZZLE *drizzle)
 {
-  return((my_bool) drizzle_real_query(drizzle, "rollback", 8));
+  return((bool) drizzle_real_query(drizzle, "rollback", 8));
 }
 
 
@@ -1052,9 +1055,9 @@
   Set autocommit to either true or false
 */
 
-my_bool STDCALL drizzle_autocommit(DRIZZLE *drizzle, my_bool auto_mode)
+bool STDCALL drizzle_autocommit(DRIZZLE *drizzle, bool auto_mode)
 {
-  return((my_bool) drizzle_real_query(drizzle, auto_mode ?
+  return((bool) drizzle_real_query(drizzle, auto_mode ?
                                          "set autocommit=1":"set autocommit=0",
                                          16));
 }
@@ -1069,9 +1072,9 @@
   to be read using drizzle_next_result()
 */
 
-my_bool STDCALL drizzle_more_results(DRIZZLE *drizzle)
+bool STDCALL drizzle_more_results(DRIZZLE *drizzle)
 {
-  my_bool res;
+  bool res;
 
   res= ((drizzle->server_status & SERVER_MORE_RESULTS_EXISTS) ? 1: 0);
   return(res);
@@ -1104,7 +1107,7 @@
   return (*drizzle->methods->use_result)(drizzle);
 }
 
-my_bool STDCALL drizzle_read_query_result(DRIZZLE *drizzle)
+bool STDCALL drizzle_read_query_result(DRIZZLE *drizzle)
 {
   return (*drizzle->methods->read_query_result)(drizzle);
 }

